@@ -308,3 +308,17 @@ loggerSetupFile <- function(log.file, default.threshold = "info", append = TRUE)
   lgr
 }
 
+#' mutate_cond
+#' @param .data data frame to apply the mutate
+#' @param condition condition to conditionally apply mutate
+#' @param ... mutation function
+#' @param envir environment to apply condition
+#' @import dplyr
+#' @export
+mutate_cond <- function(.data, condition, ..., envir = parent.frame()) {
+  condition <- eval(substitute(condition), .data, envir)
+  .data[condition, ] <- .data[condition, ] %>% mutate(...)
+  .data
+}
+
+
